/*
 * Taken from nvidia-settings: A tool for configuring the NVIDIA X driver on Unix
 * and Linux systems.
 *
 * Copyright (C) 2004 NVIDIA Corporation.
 * Copyright (c) 2004 Hamish Rodda <rodda@kde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of Version 2 of the GNU General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See Version 2
 * of the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the:
 *
 *           Free Software Foundation, Inc.
 *           59 Temple Place - Suite 330
 *           Boston, MA 02111-1307, USA
 *
 */

#ifndef ATTRIBUTEMAP_H
#define ATTRIBUTEMAP_H

#include <qstring.h>

#include <X11/extensions/NVCtrl.h>

#define RED_CHANNEL_INDEX     0
#define GREEN_CHANNEL_INDEX   1
#define BLUE_CHANNEL_INDEX    2

#define CONTRAST_INDEX        3
#define BRIGHTNESS_INDEX      4
#define GAMMA_INDEX           5

#define RED_CHANNEL            (1 << RED_CHANNEL_INDEX)
#define GREEN_CHANNEL          (1 << GREEN_CHANNEL_INDEX)
#define BLUE_CHANNEL           (1 << BLUE_CHANNEL_INDEX)
#define ALL_CHANNELS           (RED_CHANNEL|GREEN_CHANNEL|BLUE_CHANNEL)

#define CONTRAST_VALUE         (1 << CONTRAST_INDEX)
#define BRIGHTNESS_VALUE       (1 << BRIGHTNESS_INDEX)
#define GAMMA_VALUE            (1 << GAMMA_INDEX)
#define ALL_VALUES             (CONTRAST_VALUE|BRIGHTNESS_VALUE|GAMMA_VALUE)

#define NV_PARSER_TYPE_FRAMELOCK        (1<<16)
#define NV_PARSER_TYPE_COLOR_ATTRIBUTE  (1<<17)
#define NV_PARSER_TYPE_NO_CONFIG_WRITE  (1<<18)
#define NV_PARSER_TYPE_GUI_ATTRIUBUTE   (1<<19)
#define NV_PARSER_TYPE_XVIDEO_ATTRIBUTE (1<<20)

#define F NV_PARSER_TYPE_FRAMELOCK 
#define C NV_PARSER_TYPE_COLOR_ATTRIBUTE
#define N NV_PARSER_TYPE_NO_CONFIG_WRITE
#define G NV_PARSER_TYPE_GUI_ATTRIUBUTE
#define V NV_PARSER_TYPE_XVIDEO_ATTRIBUTE

typedef unsigned int uint32;

typedef struct _AttributeTableEntry {
    char *name;
    int attr;
    uint32 flags;
} AttributeTableEntry;

#define FIRSTATTRIBUTE NV_CTRL_FLATPANEL_SCALING

AttributeTableEntry attributeTable[] = {
   
    /* name                    constant                             flags */
 
    { (char*)"FlatpanelScaling",      NV_CTRL_FLATPANEL_SCALING,           0     },
    { (char*)"FlatpanelDithering",    NV_CTRL_FLATPANEL_DITHERING,         0     },
    { (char*)"DigitalVibrance",       NV_CTRL_DIGITAL_VIBRANCE,            0     },
    { (char*)"ImageSharpening",       NV_CTRL_IMAGE_SHARPENING,            0     },
    { (char*)"BusType",               NV_CTRL_BUS_TYPE,                    0     },
    { (char*)"VideoRam",              NV_CTRL_VIDEO_RAM,                   0     },
    { (char*)"Irq",                   NV_CTRL_IRQ,                         0     },
    { (char*)"OperatingSystem",       NV_CTRL_OPERATING_SYSTEM,            0     },
    { (char*)"SyncToVBlank",          NV_CTRL_SYNC_TO_VBLANK,              0     },
    { (char*)"LogAniso",              NV_CTRL_LOG_ANISO,                   0     },
    { (char*)"FSAA",                  NV_CTRL_FSAA_MODE,                   0     },
    { (char*)"TextureSharpen",        NV_CTRL_TEXTURE_SHARPEN,             0     },
    { (char*)"Ubb",                   NV_CTRL_UBB,                         0     },
    { (char*)"Overlay",               NV_CTRL_OVERLAY,                     0     },
    { (char*)"Stereo",                NV_CTRL_STEREO,                      0     },
    { (char*)"TwinView",              NV_CTRL_TWINVIEW,                    0     },
    { (char*)"ConnectedDisplays",     NV_CTRL_CONNECTED_DISPLAYS,          0     },
    { (char*)"EnabledDisplays",       NV_CTRL_ENABLED_DISPLAYS,            0     },
    { (char*)"ForceGenericCpu",       NV_CTRL_FORCE_GENERIC_CPU,           0     },
    { (char*)"GammaCorrectedAALines", NV_CTRL_OPENGL_AA_LINE_GAMMA,        0     },
    { (char*)"CursorShadow",          NV_CTRL_CURSOR_SHADOW,               0     },
    { (char*)"CursorShadowXOffset",   NV_CTRL_CURSOR_SHADOW_X_OFFSET,      0     },
    { (char*)"CursorShadowYOffset",   NV_CTRL_CURSOR_SHADOW_Y_OFFSET,      0     },
    { (char*)"CursorShadowAlpha",     NV_CTRL_CURSOR_SHADOW_ALPHA,         0     },
    { (char*)"CursorShadowRed",       NV_CTRL_CURSOR_SHADOW_RED,           0     },
    { (char*)"CursorShadowGreen",     NV_CTRL_CURSOR_SHADOW_GREEN,         0     },
    { (char*)"CursorShadowBlue",      NV_CTRL_CURSOR_SHADOW_BLUE,          0     },
    { (char*)"FSAAAppControlled",     NV_CTRL_FSAA_APPLICATION_CONTROLLED, 0     },
    { (char*)"LogAnisoAppControlled", NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED,0 },
    { (char*)"FrameLockMaster",       NV_CTRL_FRAMELOCK_MASTER,            N|F|G },
    { (char*)"FrameLockPolarity",     NV_CTRL_FRAMELOCK_POLARITY,          N|F|G },
    { (char*)"FrameLockSyncDelay",    NV_CTRL_FRAMELOCK_SYNC_DELAY,        N|F|G },
    { (char*)"FrameLockEnable",       NV_CTRL_FRAMELOCK_SYNC,              N|F|G },
    { (char*)"FrameLockSyncInterval", NV_CTRL_FRAMELOCK_SYNC_INTERVAL,     N|F|G },
    { (char*)"FrameLockHouseFormat",  NV_CTRL_FRAMELOCK_VIDEO_MODE,        N|F|G },
    { (char*)"Brightness",            BRIGHTNESS_VALUE|ALL_CHANNELS,       N|C|G },
    { (char*)"RedBrightness",         BRIGHTNESS_VALUE|RED_CHANNEL,        C|G   },
    { (char*)"GreenBrightness",       BRIGHTNESS_VALUE|GREEN_CHANNEL,      C|G   },
    { (char*)"BlueBrightness",        BRIGHTNESS_VALUE|BLUE_CHANNEL,       C|G   },
    { (char*)"Contrast",              CONTRAST_VALUE|ALL_CHANNELS,         N|C|G },
    { (char*)"RedContrast",           CONTRAST_VALUE|RED_CHANNEL,          C|G   },
    { (char*)"GreenContrast",         CONTRAST_VALUE|GREEN_CHANNEL,        C|G   },
    { (char*)"BlueContrast",          CONTRAST_VALUE|BLUE_CHANNEL,         C|G   },
    { (char*)"Gamma",                 GAMMA_VALUE|ALL_CHANNELS,            N|C|G },
    { (char*)"RedGamma",              GAMMA_VALUE|RED_CHANNEL,             C|G   },
    { (char*)"GreenGamma",            GAMMA_VALUE|GREEN_CHANNEL,           C|G   },
    { (char*)"BlueGamma",             GAMMA_VALUE|BLUE_CHANNEL,            C|G   },
    { (char*)"TVOverScan",            NV_CTRL_TV_OVERSCAN,                 0     },
    { (char*)"TVFlickerFilter",       NV_CTRL_TV_FLICKER_FILTER,           0     },
    { (char*)"TVBrightness",          NV_CTRL_TV_BRIGHTNESS,               0     },
    { (char*)"TVHue",                 NV_CTRL_TV_HUE,                      0     },
    { (char*)"TVContrast",            NV_CTRL_TV_CONTRAST,                 0     },
    { (char*)"TVSaturation",          NV_CTRL_TV_SATURATION,               0     },
    { (char*)"GPUCoreTemp",           NV_CTRL_GPU_CORE_TEMPERATURE,        N     },
    { (char*)"GPUAmbientTemp",        NV_CTRL_AMBIENT_TEMPERATURE,         N     },
	{ (char*)"FlippingAllowed",       NV_CTRL_FLIPPING_ALLOWED,            0     },

/*    { "XVideoOverlaySaturation",   NV_CTRL_ATTR_XV_OVERLAY_SATURATION,     V },
    { "XVideoOverlayContrast",     NV_CTRL_ATTR_XV_OVERLAY_CONTRAST,       V },
    { "XVideoOverlayBrightness",   NV_CTRL_ATTR_XV_OVERLAY_BRIGHTNESS,     V },
    { "XVideoOverlayHue",          NV_CTRL_ATTR_XV_OVERLAY_HUE,            V },
    { "XVideoTextureSyncToVBlank", NV_CTRL_ATTR_XV_TEXTURE_SYNC_TO_VBLANK, V },
    { "XVideoBlitterSyncToVBlank", NV_CTRL_ATTR_XV_BLITTER_SYNC_TO_VBLANK, V },*/

    { NULL,                    0,                                   0     }
};

#endif
