/*
 * Copyright (c) 2004 Hamish Rodda <rodda@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "nvidia3dmodule.h"

#include <qcheckbox.h>
#include <qwhatsthis.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qapplication.h>
#include <qdesktopwidget.h>

#include <kdebug.h>
#include <klocale.h>
#include <kcmodule.h>
#include <kglobal.h>
#include <kgenericfactory.h>
#include <kcombobox.h>
#include <kconfig.h>

#include "nvidia3dwidget.h"
#include "settingsbridge.h"
#include "attributes.h"

#include <X11/Xlib.h>
#include <X11/extensions/NVCtrl.h>

extern "C" {
	#include <X11/extensions/NVCtrlLib.h>
}

// DLL Interface for kcontrol
typedef KGenericFactory<Nvidia3DModule, QWidget > KSSFactory1;
K_EXPORT_COMPONENT_FACTORY (kcm_nvidia3d, KSSFactory1("nvidia3d") )

extern "C"
{
	void init_nvidia3d()
	{
		SettingsBridge* settings = new SettingsBridge(true);
		if (!settings->isValid())
			return;
		
		settings->loadFromDisk(false);
		settings->commitChanges();
	}

	bool test_nvidia3d()
	{
		return !XNVCTRLQueryExtension(qt_xdisplay(), 0, 0);
	}
}

Nvidia3DModule::Nvidia3DModule( QWidget * parent, const char * name, const QStringList & _args )
	: NvidiaModule(parent, name, _args)
	, m_main(new Nvidia3DWidget(this))
{
	if (!m_settings->isValid())
		return;

	if (m_settings->validScreens().count() <= 1)
		m_main->screenContainer->hide();
	
	m_settings->registerWidget(m_main->openGLFlipping, NV_CTRL_FLIPPING_ALLOWED);
	m_settings->registerWidget(m_main->openGLEnhancedCPU, NV_CTRL_FORCE_GENERIC_CPU, true);

	// FIXME workaround design of NV-CONTROL
	m_settings->registerAttribute(new CombinedAttribute(m_settings, m_main->antialiasing, NV_CTRL_FSAA_APPLICATION_CONTROLLED, NV_CTRL_FSAA_MODE), m_main->containerAntialiasing);
	m_settings->registerAttribute(new CombinedAttribute(m_settings, m_main->anisotropic, NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED, NV_CTRL_LOG_ANISO), m_main->containerAnisotropic);

	m_settings->registerWidget(m_main->textureSharpening, NV_CTRL_TEXTURE_SHARPEN);
	m_settings->registerWidget(m_main->openGLVSync, NV_CTRL_SYNC_TO_VBLANK);
	m_settings->registerWidget(m_main->openGLAALineGamma, NV_CTRL_OPENGL_AA_LINE_GAMMA);
	
	//m_settings->registerWidget(m_main->videoVSyncTexture, NV_CTRL_ATTR_XV_TEXTURE_SYNC_TO_VBLANK);
	//m_settings->registerWidget(m_main->videoVSyncBlitter, NV_CTRL_ATTR_XV_BLITTER_SYNC_TO_VBLANK);
}

#include "nvidia3dmodule.moc"
